summaryrefslogtreecommitdiffstats
path: root/gentoo/trinity-base/kopete/files/kopete-3.5.13.1-patches/0005-df8b5e2-fix-inadvertent-tq-changes.patch
blob: 968ffaf45a65c5fde9c7eba85c46e4cb06d3c88b (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
diff --git a/kopete/libkopete/tests/create_test.rb b/kopete/libkopete/tests/create_test.rb
index ba6e0c2..7951bf3 100755
--- a/kopete/libkopete/tests/create_test.rb
+++ b/kopete/libkopete/tests/create_test.rb
@@ -37,7 +37,7 @@ fileCpp.gsub!(/template/, className.downcase.gsub(/::/,""))
 fileCpp.gsub!(/Template/, className.gsub(/::/,""))
 fileCpp.gsub!(/some requirement/, className + " class.")
 
-makefileAm = "kunittest_template_test_la_SOURCES = template_test.cpp\nkunittest_template_test_la_LIBADD = -lkunittest ../tqmock/libkopete_tqmock.la\nkunittest_template_test_la_LDFLAGS = -module $(KDE_CHECK_PLUGIN) $(all_libraries)\n"
+makefileAm = "kunittest_template_test_la_SOURCES = template_test.cpp\nkunittest_template_test_la_LIBADD = -lkunittest ../mock/libkopete_mock.la\nkunittest_template_test_la_LDFLAGS = -module $(KDE_CHECK_PLUGIN) $(all_libraries)\n"
 makefileAm.gsub!(/template/, className.downcase.gsub(/::/,""))
 
 hNew = hBase.gsub(/template/, className.downcase.gsub(/::/,""))
diff --git a/kopete/libkopete/tests/kopetemessage_test.cpp b/kopete/libkopete/tests/kopetemessage_test.cpp
index bfd9e39..57908e4 100644
--- a/kopete/libkopete/tests/kopetemessage_test.cpp
+++ b/kopete/libkopete/tests/kopetemessage_test.cpp
@@ -29,11 +29,11 @@
 #include <kdebug.h>
 
 #include "kopetemessage_test.h"
-#include "kopeteaccount_tqmock.h"
-#include "kopeteprotocol_tqmock.h"
-#include "kopetecontact_tqmock.h"
-#include "kopetemetacontact_tqmock.h"
-#include "kopeteaccount_tqmock.h"
+#include "kopeteaccount_mock.h"
+#include "kopeteprotocol_mock.h"
+#include "kopetecontact_mock.h"
+#include "kopetemetacontact_mock.h"
+#include "kopeteaccount_mock.h"
 
 using namespace KUnitTest;
 
diff --git a/kopete/libkopete/tests/mock/kopeteaccount_mock.cpp b/kopete/libkopete/tests/mock/kopeteaccount_mock.cpp
index 8beb6e8..7d46fc3 100644
--- a/kopete/libkopete/tests/mock/kopeteaccount_mock.cpp
+++ b/kopete/libkopete/tests/mock/kopeteaccount_mock.cpp
@@ -1,5 +1,5 @@
 /*
-    Account tqmock object class
+    Account mock object class
 
     Copyright (c) 2005 by Duncan Mac-Vicar Prett  <duncan@kde.org>
 
@@ -15,9 +15,9 @@
     *************************************************************************
 */
 
-#include "kopeteaccount_tqmock.h"
+#include "kopeteaccount_mock.h"
 #include "kopetemetacontact.h"
-#include "kopeteaccount_tqmock.h"
+#include "kopeteaccount_mock.h"
 
 namespace Kopete
 {
diff --git a/kopete/libkopete/tests/mock/kopeteaccount_mock.h b/kopete/libkopete/tests/mock/kopeteaccount_mock.h
index be4f281..039632f 100644
--- a/kopete/libkopete/tests/mock/kopeteaccount_mock.h
+++ b/kopete/libkopete/tests/mock/kopeteaccount_mock.h
@@ -1,5 +1,5 @@
 /*
-    Account tqmock object class
+    Account mock object class
 
     Copyright (c) 2005 by Duncan Mac-Vicar Prett  <duncan@kde.org>
 
diff --git a/kopete/libkopete/tests/mock/kopetecontact_mock.cpp b/kopete/libkopete/tests/mock/kopetecontact_mock.cpp
index 43a5b81..ea90bee 100644
--- a/kopete/libkopete/tests/mock/kopetecontact_mock.cpp
+++ b/kopete/libkopete/tests/mock/kopetecontact_mock.cpp
@@ -1,5 +1,5 @@
 /*
-    Contact tqmock object class
+    Contact mock object class
 
     Copyright (c) 2005 by Duncan Mac-Vicar Prett  <duncan@kde.org>
 
@@ -15,7 +15,7 @@
     *************************************************************************
 */
 
-#include "kopetecontact_tqmock.h"
+#include "kopetecontact_mock.h"
 
 namespace Kopete
 {
diff --git a/kopete/libkopete/tests/mock/kopetecontact_mock.h b/kopete/libkopete/tests/mock/kopetecontact_mock.h
index aba361a..00ec878 100644
--- a/kopete/libkopete/tests/mock/kopetecontact_mock.h
+++ b/kopete/libkopete/tests/mock/kopetecontact_mock.h
@@ -1,5 +1,5 @@
 /*
-    Contact tqmock object class
+    Contact mock object class
 
     Copyright (c) 2005 by Duncan Mac-Vicar Prett  <duncan@kde.org>
 
diff --git a/kopete/libkopete/tests/mock/kopetemessage_mock.cpp b/kopete/libkopete/tests/mock/kopetemessage_mock.cpp
index 66f325e..a3e543e 100644
--- a/kopete/libkopete/tests/mock/kopetemessage_mock.cpp
+++ b/kopete/libkopete/tests/mock/kopetemessage_mock.cpp
@@ -1,5 +1,5 @@
 /*
-    Message tqmock object class
+    Message mock object class
 
     Copyright (c) 2005 by Duncan Mac-Vicar Prett  <duncan@kde.org>
 
@@ -15,6 +15,6 @@
     *************************************************************************
 */
 
-#include "kopetemessage_tqmock.h"
+#include "kopetemessage_mock.h"
 
 
diff --git a/kopete/libkopete/tests/mock/kopetemessage_mock.h b/kopete/libkopete/tests/mock/kopetemessage_mock.h
index f8677ee..1345e92 100644
--- a/kopete/libkopete/tests/mock/kopetemessage_mock.h
+++ b/kopete/libkopete/tests/mock/kopetemessage_mock.h
@@ -1,5 +1,5 @@
 /*
-    Message tqmock object class
+    Message mock object class
 
     Copyright (c) 2005 by Duncan Mac-Vicar Prett  <duncan@kde.org>
 
diff --git a/kopete/libkopete/tests/mock/kopetemetacontact_mock.cpp b/kopete/libkopete/tests/mock/kopetemetacontact_mock.cpp
index e9cc95a..32f0fe1 100644
--- a/kopete/libkopete/tests/mock/kopetemetacontact_mock.cpp
+++ b/kopete/libkopete/tests/mock/kopetemetacontact_mock.cpp
@@ -15,6 +15,6 @@
     *************************************************************************
 */
 
-#include "kopetemetacontact_tqmock.h"
+#include "kopetemetacontact_mock.h"
 
 
diff --git a/kopete/libkopete/tests/mock/kopeteprotocol_mock.h b/kopete/libkopete/tests/mock/kopeteprotocol_mock.h
index d2ad36f..db40740 100644
--- a/kopete/libkopete/tests/mock/kopeteprotocol_mock.h
+++ b/kopete/libkopete/tests/mock/kopeteprotocol_mock.h
@@ -1,5 +1,5 @@
 /*
-    Protocol tqmock object class
+    Protocol mock object class
 
     Copyright (c) 2005 by Duncan Mac-Vicar Prett  <duncan@kde.org>
diff --git a/kopete/libkopete/tests/mock/kopeteprotocol_mock.cpp b/kopete/libkopete/tests/mock/kopeteprotocol_mock.cpp
index 97bcfee..d9ae1d3 100644
--- a/kopete/libkopete/tests/mock/kopeteprotocol_mock.cpp
+++ b/kopete/libkopete/tests/mock/kopeteprotocol_mock.cpp
@@ -1,5 +1,5 @@
 /*
-    Protocol tqmock object class
+    Protocol mock object class
 
     Copyright (c) 2005 by Duncan Mac-Vicar Prett  <duncan@kde.org>
 
@@ -15,7 +15,7 @@
     *************************************************************************
 */
 
-#include "kopeteprotocol_tqmock.h"
+#include "kopeteprotocol_mock.h"
 
 namespace Kopete
 {
@@ -44,6 +44,6 @@ KopeteEditAccountWidget* Protocol::createEditAccountWidget( Kopete::Account *acc
 	return 0L;
 }
 
-} // end ns tqmock
+} // end ns mock
 } // end ns test
 } // end ns kopete